@@ -4,32 +4,7 @@
 # multiprocessing/forking.py
 #
 # Copyright (c) 2006-2008, R Oudkerk
-# All rights reserved.
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions
-# are met:
-#
-# 1. Redistributions of source code must retain the above copyright
-#    notice, this list of conditions and the following disclaimer.
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions and the following disclaimer in the
-#    documentation and/or other materials provided with the distribution.
-# 3. Neither the name of author nor the names of any contributors may be
-#    used to endorse or promote products derived from this software
-#    without specific prior written permission.
-#
-# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND
-# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
-# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
-# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
-# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-# SUCH DAMAGE.
+# Licensed to PSF under a Contributor Agreement.
 #
 
 from __future__ import absolute_import
@@ -37,6 +12,7 @@ from __future__ import absolute_import
 import os
 import sys
 import signal
+import warnings
 
 from ._ext import Connection, PipeConnection, win32
 from pickle import load, HIGHEST_PROTOCOL
@@ -50,6 +26,13 @@ try:
 except NameError:
     class WindowsError(Exception): pass  # noqa
 
+W_OLD_DJANGO_LAYOUT = """\
+Will add directory %r to path! This is necessary to accommodate \
+pre-Django 1.4 layouts using setup_environ.
+You can skip this warning by adding a DJANGO_SETTINGS_MODULE=settings \
+environment variable.
+"""
+
 #
 # Choose whether to do a fork or spawn (fork+exec) on Unix.
 # This affects how some shared resources should be created.
@@ -188,6 +171,7 @@ if sys.platform != 'win32':
         _tls = thread._local()
 
         def __init__(self, process_obj):
+            _Django_old_layout_hack__save()
             sys.stdout.flush()
             sys.stderr.flush()
             self.returncode = None
@@ -319,6 +303,7 @@ else:
         _tls = thread._local()
 
         def __init__(self, process_obj):
+            _Django_old_layout_hack__save()
             # create pipe for communication with child
             rfd, wfd = os.pipe()
 
@@ -449,11 +434,55 @@ def get_command_line():
         return [_python_exe, '-c', prog, '--billiard-fork']
 
 
+def _Django_old_layout_hack__save():
+    if 'DJANGO_PROJECT_DIR' not in os.environ:
+        try:
+            settings_name = os.environ['DJANGO_SETTINGS_MODULE']
+        except KeyError:
+            return  # not using Django.
+
+        try:
+            project_name, _ = settings_name.split('.', 1)
+        except ValueError:
+            return  # not modified by setup_environ
+
+        project = __import__(project_name)
+        try:
+            project_dir = os.path.normpath(_module_parent_dir(project))
+        except AttributeError:
+            return  # dynamically generated module (no __file__)
+        warnings.warn(UserWarning(
+            W_OLD_DJANGO_LAYOUT % os.path.realpath(project_dir)
+        ))
+        os.environ['DJANGO_PROJECT_DIR'] = project_dir
+
+
+def _Django_old_layout_hack__load():
+    try:
+        sys.path.append(os.environ['DJANGO_PROJECT_DIR'])
+    except KeyError:
+        pass
+
+
+def _module_parent_dir(mod):
+    dir, filename = os.path.split(_module_dir(mod))
+    if dir == os.curdir or not dir:
+        dir = os.getcwd()
+    return dir
+
+
+def _module_dir(mod):
+    if '__init__.py' in mod.__file__:
+        return os.path.dirname(mod.__file__)
+    return mod.__file__
+
+
 def main():
     '''
     Run code specifed by data received over pipe
     '''
     global _forking_is_enabled
+    _Django_old_layout_hack__load()
 
     assert is_forking(sys.argv)
     _forking_is_enabled = False
